import React from "react";
import { FixedTo, GetFixedPositionOptions, OptionalFixedPositionOptions } from "@react-md/transition";
import { LabelRequiredForA11y } from "@react-md/utils";
import { BaseDialogProps } from "./Dialog";
export interface BaseFixedDialogProps extends Omit<BaseDialogProps, "type">, Pick<OptionalFixedPositionOptions, "anchor"> {
    /**
     * The element the dialog should be fixed to. This can either be:
     * - a query selector string to get an element
     * - an HTMLElement (normally a ref.current)
     * - a function that returns an HTMLElement or null
     * - null
     */
    fixedTo: FixedTo;
    /**
     * Any additional options to apply to the fixed positioning logic. The
     * `transformOrigin` option will be enabled by default.
     */
    options?: OptionalFixedPositionOptions;
    /**
     * An optional function to call to get the fixed positioning options.
     */
    getOptions?: GetFixedPositionOptions;
}
export declare type FixedDialogProps = LabelRequiredForA11y<BaseFixedDialogProps>;
/**
 * The `FixedDialog` is a wrapper for the `Dialog` component that can be used to
 * be fix itself to another element. Another term for this component might be a
 * "Pop out Dialog".
 */
export declare const FixedDialog: React.ForwardRefExoticComponent<FixedDialogProps & React.RefAttributes<HTMLDivElement>>;
